"use strict";
(self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] = self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] || []).push([[3901],{

/***/ 93901:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   createArchitectureServices: () => (/* reexport safe */ _chunk_O7ZBX7Z2_mjs__WEBPACK_IMPORTED_MODULE_0__.i)
/* harmony export */ });
/* harmony import */ var _chunk_O7ZBX7Z2_mjs__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(17711);
/* harmony import */ var _chunk_FPAJGGOC_mjs__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(82093);





/***/ })

}]);
//# sourceMappingURL=3901.7873f08dec99dacc4661.js.map?v=7873f08dec99dacc4661